package com.emato.eoss.msg.service;

import com.google.common.base.Strings;

import java.io.Serializable;

/**
 * 通用消息封装
 * @author Scott Chen
 * @date 2017-09-19 16:60
 * @Description:
 */
public class Message implements Serializable {

	private static final long serialVersionUID = 4081619286503989887L;

	private boolean success;

	/**
	 * 消息代码
	 */
	private String code;
	/**
	 * 消息内容体
	 */
	private String msg;
	/**
	 * 扩展
	 */
	private Object extend;

	private Message() {
	}

	public String getCode() {
		return code;
	}
	public String getMsg() {
		return msg;
	}
	public Object getExtend() {
		return extend;
	}
	public boolean isSuccess() {
		return success;
	}

	public static Builder builder() {
		return new Builder();
	}
	public static Builder builder(String code, String msg) {
		return new Builder(code, msg);
	}
	public static Builder builder(String code, String msg, Object extend) {
		return new Builder(code, msg, extend);
	}


	//---------- 直接返回结果 ----------
	public static Message success() {
		return new Builder().build();
	}
	public static Message success(Object object) {
		Builder builder = new Builder();
		return builder.setExtend(object).build();
	}

	public static Message success(String msg) {
		return new Builder(MessageStatus.SUCCESS.innerCode, msg).build();
	}

	public static Message success(String msg, Object object) {
		Builder builder = new Builder(MessageStatus.SUCCESS.innerCode, msg, object);
		return builder.build();
	}

	public static Message success(String code, String msg, Object object) {
		Builder builder = new Builder(code, msg, object);
		return builder.build();
	}


	//--- 错误----------
	public static Message error() {
		return new Builder(MessageStatus.ERROR.innerCode, MessageStatus.ERROR.innerMsg).build();
	}
	public static Message error(String msg) {
		return new Builder(MessageStatus.ERROR.innerCode, msg).build();
	}
	public static Message error(String code, String msg) {
		return new Builder(code, msg).build();
	}

	//--- 失败----------
	public static Message failed() {
		return new Builder(MessageStatus.FAILURE.innerCode, MessageStatus.FAILURE.innerMsg).build();
	}
	public static Message failed(String msg) {
		return new Builder(MessageStatus.FAILURE.innerCode, msg).build();
	}
	public static Message failed(String code, String msg) {
		return new Builder(code, msg).build();
	}


	/**
	 * 消息构建器类
	 */
	public static class Builder {

		private boolean success;
		private String code;
		private String msg;
		private Object extend;

		public Builder() {
			this.success = true;
			this.code = MessageStatus.SUCCESS.innerCode;
			this.msg = MessageStatus.SUCCESS.innerMsg;
			this.extend = null;
		}

		public Builder(String code, String msg) {
			this.code = Strings.isNullOrEmpty(code) ? MessageStatus.SUCCESS.innerCode : code;
			this.msg = Strings.isNullOrEmpty(msg) ? MessageStatus.SUCCESS.innerMsg : msg;
			this.success = this.code.equals(MessageStatus.SUCCESS.innerCode) ? true : false;
		}

		public Builder(String code, String msg, Object extend) {
			this.code = Strings.isNullOrEmpty(code) ? MessageStatus.SUCCESS.innerCode : code;
			this.msg = Strings.isNullOrEmpty(msg) ? MessageStatus.SUCCESS.innerMsg : msg;
			this.extend = extend;
			this.success = this.code.equals(MessageStatus.SUCCESS.innerCode) ? true : false;
		}

		public Message build() {
			Message message = new Message();
			message.success = this.success;
			message.code = this.code;
			message.msg = this.msg;
			message.extend = this.extend;
			return message;
		}

		public Builder setSuccess(boolean success) {
			this.success = success;
			return this;
		}

		public Builder setCode(String code) {
			this.code = code;
			return this;
		}

		public Builder setMsg(String msg) {
			this.msg = msg;
			return this;
		}

		public Builder setExtend(Object extend) {
			this.extend = extend;
			return this;
		}


	}

}
